/*
 * 19:06:54 14/05/00
 *
 * QuestionSetClient.java - Le client
 * Copyright (C) 2000 Romain Guy
 * guy.romain@bigfoot.com
 * http://www.chez.com/powerteam
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

import java.awt.*;
import java.awt.event.*;

import javax.swing.*;
import javax.swing.border.*;

import java.util.StringTokenizer;

import java.io.IOException;
import java.io.BufferedReader;
import java.io.InputStreamReader;

import com.chez.powerteam.caffeine.CaffeineClient;
import com.chez.powerteam.caffeine.event.NetworkEvent;
import com.chez.powerteam.caffeine.event.NetworkListener;

/**
 * Ceci est le client qui demande les questions, les traite puis retourne la rponse
 * de l'utilisateur.
 */

public class QuestionSetClient extends JFrame implements NetworkListener, ActionListener
{
  // la connexion
  private CaffeineClient client;
  // nombre de points
  private int points = 0;
  // index de la question
  private int questionIndex = 0;

  // les membres suivants sont spcifiques au GUI
  private QuestionPanel pane;
  // bouton Ok
  private JButton ok;
  // label du score
  private JLabel score;

  /**
   * Cre un client se connectant sur un serveur d'IP donne.
   */

  public QuestionSetClient(String IP)
  {
    super("Login: Quiz");
    getContentPane().setLayout(new BorderLayout());

    // paramtres: IP du serveur, numro de port
    client = new CaffeineClient(IP, 1705);
    client.addNetworkListener(this);

    EmptyBorder border = new EmptyBorder(4, 4, 4, 4);

    pane = new QuestionPanel();
    pane.setBorder(border);
    getContentPane().add(BorderLayout.CENTER, pane);

    JPanel _pane = new JPanel(new BorderLayout());
    _pane.add(BorderLayout.WEST, ok = new JButton("Ok"));
    _pane.add(BorderLayout.EAST, score = new JLabel());
    _pane.setBorder(new CompoundBorder(
                    new CompoundBorder(border, new LineBorder(score.getForeground())),
                    border));
    ok.addActionListener(this);
    getContentPane().add(BorderLayout.SOUTH, _pane);

    requestQuestion();

    addWindowListener(new WindowAdapter()
    {
      public void windowClosing(WindowEvent evt)
      {
        shutdown();
      }
    });

    pack();
    centerComponent(this);
    setResizable(false);
    setVisible(true);
  }

  /**
   * Demande une question au serveur.
   */

  private void requestQuestion()
  {
    client.send("?");
    score.setText("Score: " + points + "/" + questionIndex);
    questionIndex++;
  }

  /**
   * Ceci arrive lorsque nous recevons un message du serveur.
   */

  public void networkEvent(NetworkEvent evt)
  {
    String msg = evt.getString();

    // vrifions la nature du message
    switch (msg.charAt(0))
    {
      // une question arrive !!
      case '?':
        handleQuestion(msg.substring(1));
        break;

      // rponse ($1 si bonne, $0 si mauvaise)
      case '$':
        switch (msg.charAt(1))
        {
          case '0':
            badAnswer();
            break;
          case '1':
            goodAnswer();
            break;
        }
        break;

      // oops ! plus de questions  poser
      case '%':
        shutdown();
        break;
    }
  }

  /**
   * Gre l'affichage des questions. Il faut pour cela dcouper la String.
   */

  private void handleQuestion(String question)
  {
    pane.reset();

    // un '#' spare les lments de la question
    StringTokenizer tokens = new StringTokenizer(question, "#");

    // le premier token est la question elle mme
    pane.setQuestion("Question " + questionIndex + ": " + tokens.nextToken());

    String ID;
    String token;

    while (tokens.hasMoreTokens())
    {
      token = tokens.nextToken();
      int index = token.indexOf('$');
      ID = token.substring(0, index);

      pane.addChoosableItem(ID, token.substring(index + 1));
    }

    pack();
    centerComponent(this);
  }

  public void actionPerformed(ActionEvent evt)
  {
    if (evt.getSource() == ok)
    {
      String answer = pane.getSelectedAnswer();
      if (answer != null)
        client.send('$' + answer);
    }
  }

  /**
   * Si la rponse donne tait bonne.
   */

  private void goodAnswer()
  {
    points++;
    requestQuestion();
  }

  /**
   * Si la rponse donne tait mauvais.
   */

  private void badAnswer()
  {
    requestQuestion();
  }

  /**
   * Nous n'avons plus de questions auxquelles rpondre, bye'bye'cha !
   */

  private void shutdown()
  {
    showMessage("Total:\n" + points + " bonnes rponses sur " + (questionIndex - 1));
    client.stop();
    dispose();
    System.exit(0);
  }

  public static Dimension getScreenDimension()
  {
    return Toolkit.getDefaultToolkit().getScreenSize();
  }

  public static void centerComponent(Component compo)
  {
    compo.setLocation(new Point((getScreenDimension().width - compo.getSize().width) / 2,
                      (getScreenDimension().height - compo.getSize().height) / 2));
  }

  public static void showMessage(String message)
  {
    JOptionPane.showMessageDialog(null, message, "Login: Quiz",
                                  JOptionPane.INFORMATION_MESSAGE);
  }
}

// End of QuestionSetClient.java
