/*
 * 05/09/2000 - 18:33:08
 *
 * QuestionSetHandler.java - Cre un set de question depuis un fichier XML
 * Copyright (C) 2000 Romain Guy
 * guy.romain@bigfoot.com
 * www.chez.com/powerteam
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

import java.util.Stack;
import java.util.Vector;

import com.microstar.xml.*;

/**
 * La classe <code>QuestionSetHandler</code> lit un ensemble de questions et
 * leurs rponses associes depuis un fichier XML. Ceci permet de lire et
 * crire facilement de nouveau questionnaires.
 * @author Romain Guy <guy.romain@bigfoot.com>
 * @version 1.0
 */

public class QuestionSetHandler extends HandlerBase
{
  // vecteur contenant la srie de questions et leurs rponses
  private Vector questionsSet;
  // pile pour connaitre le dernier tag
  private Stack stateStack;

  // variables utilises pour crer les questions
  private String qGood, qQuestion;
  // variables pour les rponses
  private String aID, aAnswer;
  // quel tait le dernier attribut ?
  private String lastAttr;

  // question courante
  private Question question;

  /**
   * Retourne le set de questions cr.
   */

  public Vector getQuestionsSet()
  {
    return questionsSet;
  }

  /**
   * Constructeur. RAS.
   */

  public QuestionSetHandler() { }

  /**
   * Cette mthode parcoure une String pour grer les squences
   * d'chappement classiques telles que \n ou \t.
   * @param in La String contenant le texte
   */

  private String parse(String in)
  {
    StringBuffer _out = new StringBuffer(in.length());
    char c = '\0';
    for (int i = 0; i < in.length(); i++)
    {
      switch(c = in.charAt(i))
      {
        case '\\':
          if (i < in.length() - 1)
          {
            char p = '\0';
            switch(p = in.charAt(++i))
            {
              case 'n':
                _out.append('\n');
                break;
              case 'r':
                _out.append('\r');
                break;
              case 't':
                _out.append('\t');
                break;
              case 'w':
                _out.append(' ');
                break;
              case '\\':
                _out.append('\\');
                break;
            }
          } else
            _out.append(c);
          break;
        default:
          _out.append(c);
          break;
      }
    }
    return _out.toString();
  }

  /**
   * Le parser appelle cette mthode lorsqu'un attribut est lu.
   */

  public void attribute(String aname, String value, boolean isSpecified)
  {
    if (aname.equalsIgnoreCase("GOOD"))
      qGood = value;
    else if (aname.equalsIgnoreCase("ID"))
      aID = value;
    lastAttr = aname;
  }

  /**
   * Cette mthode vrifie que le fichier XML est bien du type attendu.
   * C'est  dire que la premier tag correspond bien  celui attendu.
   * Dans notre cas: QUESTION-SET
   */

  public void doctypeDecl(String name, String publicId, String systemId) throws Exception
  {
    if (!"QUESTION-SET".equalsIgnoreCase(name))
      throw new Exception("Ce fichier ne dfinit pas un set de questions !");
  }

  /**
   * Pour traiter les donnes contenues entre les deux tags d'ouverture
   * et de fermeture.
   */

  public void charData(char[] c, int off, int len)
  {
    String lastTag = (String) stateStack.peek();

    if (lastTag.equalsIgnoreCase("QUESTION"))
    {
      // subtilit: on lit la chane de caractre, on y supprime les
      // espaces de dbut et de fin. Si la rsultat est de longueur 0,
      // alors c'est simplement une indentation dans le fichier XML, nous
      // ne gardons pas cette chane
      
      String _question = new String(c, off, len);
      _question = _question.trim();

      if (_question.length() > 0)
        qQuestion = parse(_question);

    } else if (lastTag.equalsIgnoreCase("ANSWER"))
      aAnswer = parse(new String(c, off, len));
  }

  /**
   * Un tag est rencontr.
   */

  public void startElement(String name)
  {
    // on place sur la pile le nom du tag
    stateStack.push(name);

    if (name.equalsIgnoreCase("QUESTION"))
      question = new Question();
  }

  /**
   * Tag de fermeture.
   */

  public void endElement(String name)
  {
    if (name == null)
      return;
    String lastStartTag = (String) stateStack.peek();

    if (name.equalsIgnoreCase(lastStartTag))
    {
      if (lastStartTag.equalsIgnoreCase("QUESTION"))
      {
        if (qGood == null || qQuestion == null)
          System.err.println("Tag question mal form (question ou bonne rponse manquante)");

        question.setQuestion(qQuestion);
        qQuestion = null;

        question.setGoodAnswer(qGood);
        qGood = null;

        questionsSet.addElement(question);
        question = null;

      } else if (lastStartTag.equalsIgnoreCase("ANSWER")) {
        if (aID == null || aAnswer == null)
          System.err.println("Tag answer mal form (ID ou rponse manquante)");

        question.addAnswer(new Answer(aID, aAnswer));
        aID = null;
        aAnswer = null;
      }

      // on enlve le tag du haut de la pile
      stateStack.pop();
    } else
      System.err.println("XQuestions: Tag non ferm: " + stateStack.peek());

    lastAttr = null;
  }

  /**
   * Le fichier commence  tre lu.
   */

  public void startDocument()
  {
    // on initialise notre vecteur
    questionsSet = new Vector();

    try
    {
      stateStack = new Stack();
      stateStack.push(null);
    } catch (Exception e) { }
  }
}

// End of QuestionSetHandler.java
