/*
 * 17:35:04 14/05/00
 *
 * QuestionSetServer.java - Le serveur
 * Copyright (C) 2000 Romain Guy
 * guy.romain@bigfoot.com
 * http://www.chez.com/powerteam
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

import java.util.Vector;
import java.util.Hashtable;

import java.io.IOException;
import java.io.BufferedReader;
import java.io.InputStreamReader;

import com.chez.powerteam.caffeine.CaffeineServer;
import com.chez.powerteam.caffeine.CaffeineSocket;
import com.chez.powerteam.caffeine.event.ServerEvent;
import com.chez.powerteam.caffeine.event.ServerListener;

/**
 * Cette classe permet de distribuer les questions sur le rseau
 * en crant un serveur.
 */

public class QuestionSetServer extends CaffeineServer implements ServerListener
{
  // le vecteur contenant les questions
  private Vector questionSet;
  // hashtable contenant l'index de la question relative  chaque client
  private Hashtable indexes = new Hashtable();

  /**
   * Constructeur. Celui-ci cre le serveur ainsi que les questions.
   * @param questions Le fichier XML contenant les questions
   */

  public QuestionSetServer(String questions)
  {
    // paramtres: port, nom du serveur, mot de passe, max de connexions
    super(1705, "Login: Quiz", null, 25);
    addServerListener(this);

    // on lit les questions
    questionSet = QuestionSetReader.read(
                  QuestionSet.class.getResourceAsStream(questions),
                  questions);
  }

  /**
   * Cette mthode est appele lorsque l'on reoit un message en provenance
   * d'un client.
   */

  public void serverEvent(ServerEvent evt)
  {
    // la requte
    String request = evt.getString();
    // le client
    CaffeineSocket client = evt.getSender();

    // nous rcuprons le numro de la question
    int index = 0;
    Integer _index = (Integer) indexes.get(client);
    if (_index == null)
      indexes.put(client, new Integer(0));
    else
      index = _index.intValue();

    // si nous avons puis les questions
    if (index == questionSet.size())
    {
      // nous renvoyons le code terminal
      client.getOut().println("%");
      client.getOut().flush();
    }

    // analyse de la requte
    switch (request.charAt(0))
    {
      // on nous demande la question
      case '?':
        // donc nous l'envoyons au client
        sendQuestion(index, client);
        break;

      // on nous propose une rponse
      case '$':
        // donc nous la vrifions
        checkAnswer(index, client, request.substring(1));
        break;
    }
  }

  /**
   * Cette mthode vrifie la rponse et renvoi le code correspondant.
   */

  private void checkAnswer(int index, CaffeineSocket client, String answer)
  {
    // question
    Question question = (Question) questionSet.elementAt(index);

    // envoi
    client.getOut().println(question.isGoodAnswer(answer) ? "$1" : "$0");
    client.getOut().flush();

    indexes.put(client, new Integer(index + 1));
  }

  /**
   * Cette mthode cre une String contenant la question et ses rponses, formattes
   * de sorte que le client puisse distinguer les questions des rponses.
   */

  private void sendQuestion(int index, CaffeineSocket client)
  {
    // question
    Question question = (Question) questionSet.elementAt(index);
    StringBuffer buf = new StringBuffer();
    buf.append('?').append(question.getQuestion()).append('#');

    // on prend les rponses
    Answer[] answers = question.getAnswers();
    for (int j = 0; j < answers.length; j++)
    {
      buf.append(answers[j].getAnswerID()).append('$').append(answers[j].getAnswer());
      if (j < answers.length - 1)
        buf.append('#');
    }

    // envoi
    client.getOut().println(buf.toString());
    client.getOut().flush();
  }
}

// End of QuestionSetServer.java
