/*
 * NetworkEvent.java - The Caffeine client network event
 * Copyright (C) 1999 Romain Guy
 * powerteam@chez.com
 * http://www.chez.com/powerteam
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package com.chez.powerteam.caffeine.event;

/**
 * A network event, fired by CaffeineClient and used by applications
 * to receive objects from server.
 * @author Romain Guy
 */

public class NetworkEvent
{
  // the embedded object
  private Object obj;

  /**
   * Create a new NetworkEvent which will be used by applications
   * @param obj The embedded object
   */

  public NetworkEvent(Object obj)
  {
    this.obj = obj;
  }

  /**
   * The application will resolve the object for their own internal
   * work.
   * @return The embedded object
   */

  public Object getObject()
  {
    return obj;
  }

  /**
   * This can avoid applications to type-cast a string
   * @return A string representation of the object
   */

  public String getString()
  {
    return (String) obj;
  }
}

// End of NetworkEvent.java
