/*
 * ServerEvent.java - The Caffeine server event
 * Copyright (C) 1999 Romain Guy
 * powerteam@chez.com
 * http://www.chez.com/powerteam
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package com.chez.powerteam.caffeine.event;

import com.chez.powerteam.caffeine.CaffeineSocket;

/**
 * A server event, fired by CaffeineServer when it receive
 * a string from any client.
 * @author Romain Guy
 */

public class ServerEvent
{
  // the socket sender
  private CaffeineSocket socket;
  // the received string
  private String line;

  /**
   * Create a new ServerEvent which will be used by applications
   * to manage the server.
   * @param line The <code>String</code> received
   * @param socket The sender
   */

  public ServerEvent(String line, CaffeineSocket socket)
  {
    this.line = line;
    this.socket = socket;
  }

  /**
   * The application will be able to use the sender's attributes
   * to monitor the server.
   * @return The <code>CaffeineSocket</code> sender
   */

  public CaffeineSocket getSender()
  {
    return socket;
  }

  /**
   * The application will be able to use the received line
   * to monitor the server or to write a log.
   * @return The <code>String</code> received
   */

  public String getString()
  {
    return line;
  }
}

// End of ServerEvent.java
