/*
 * CaffeineServerException.java - An exception which can be thrown by the server
 * Copyright (C) 1999 Romain Guy
 * powerteam@chez.com
 * http://www.chez.com/powerteam
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package com.chez.powerteam.caffeine.exception;

import com.chez.powerteam.caffeine.CaffeineServer;

public class CaffeineServerException extends Throwable
{
  // the exception 'thrower'
  private CaffeineServer server;
  // the error message
  private String message;

  /**
   * Create a new exception which is normally thrown by the server.
   * @param server The 'thrower'
   * @param message The error message
   */

  public CaffeineServerException(CaffeineServer server, String message)
  {
    this.server = server;
    this.message = message;
  }

  /**
   * If you created a multi-server manager, this can be very useful.
   * @return The <code>CaffeineServer</code> which has thrown the exception
   */

  public CaffeineServer getThrower()
  {
    return server;
  }

  /**
   * An human readable description of the error.
   * @return A <code>String</code> containing the description of the error
   */

  public String toString()
  {
    StringBuffer buf = new StringBuffer(message.length());
    buf.append("The CaffeineServer of name ").append(server.getName());
    buf.append(" running on port ").append(server.getPort());
    buf.append(" has encountered following error:\n").append(message);
    return buf.toString();
  }
}

// End of CaffeineServerException.java

