/*
 * DefaultCaffeineFilter.java - A default Object filter for Caffeine
 * Copyright (C) 1999 Romain Guy
 * powerteam@chez.com
 * http://www.chez.com/powerteam
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package com.chez.powerteam.caffeine.filter;

import com.chez.powerteam.caffeine.*;

/**
 * The <code>DefaultCaffeineFilter</code> is the default implementation
 * of the <code>CaffeineFilter</code> interface. This class just send
 * a description of an object by calling <code>toString()</code>.
 * If you need more complexes operations, create your own filter.
 * @author Romain Guy
 */

public class DefaultCaffeineFilter implements CaffeineFilter
{
  // this is the Caffeine client owner
  private CaffeineClient parent;

  /**
   * Attach a new filter with a CaffeineClient.
   * @param clientParent The <code>CaffeineClient</code> which will use this filter
   */

  public DefaultCaffeineFilter(CaffeineClient clientParent)
  {
    this.parent = clientParent;
  }

  /**
   * Filter the object. This method first translate this object into
   * a <code>String</code> because without RMI only Strings can be
   * sent through networks.
   * @param o The <code>Object</code> which description has to be sent
   */

  public void filterOut(Object o)
  {
    // paranoia
    if (parent == null) return;
    parent.sendString(o.toString());
  }

  /**
   * Filter the object. This method will send the String to the
   * client. Then, the String will be sent by the event system to
   * all the listeners.
   * @param s The <code>String</code> received from the server
   */

  public void filterIn(String s)
  {
    // paranoia
    if (parent == null) return;
    parent.fireEvent(s);
  }
}

// End of DefaultCaffeineFilter.java
